Package: MPAC
Title: Multi-omic Pathway Analysis of Cells
Version: 1.6.0
Authors@R: c(
    person(given="Peng", family="Liu", 
           email="pliu55.wisc+bioconductor@gmail.com", 
           role = c("aut", "cre"), comment=c(ORCID="0000-0001-5655-2259")),
    person(given="Paul",    family="Ahlquist", role = c("aut")),
    person(given="Irene",   family="Ong",      role = c("aut")),
    person(given="Anthony", family="Gitter",   role = c("aut")))
Description: Multi-omic Pathway Analysis of Cells (MPAC), integrates 
    multi-omic data for understanding cellular mechanisms. It  
    predicts novel patient groups with distinct pathway profiles 
    as well as identifying key pathway proteins with potential clinical 
    associations. From CNA and RNA-seq data, it determines genes’ DNA and RNA
    states (i.e., repressed, normal, or activated), which serve as the input 
    for PARADIGM to calculate Inferred Pathway Levels (IPLs). It also permutes
    DNA and RNA states to create a background distribution to filter IPLs as a 
    way to remove events observed by chance. It provides multiple methods for
    downstream analysis and visualization.
License: GPL-3
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Depends: R (>= 4.4.0)
URL: https://github.com/pliu55/MPAC
BugReports: https://github.com/pliu55/MPAC/issues
Imports: data.table (>= 1.14.2), SummarizedExperiment (>= 1.30.2),
        BiocParallel (>= 1.28.3), fitdistrplus (>= 1.1), igraph (>=
        1.4.3), BiocSingular (>= 1.10.0), S4Vectors (>= 0.32.3),
        SingleCellExperiment (>= 1.16.0), bluster (>= 1.4.0), fgsea (>=
        1.20.0), scran (>= 1.22.1), ComplexHeatmap (>= 2.16.0),
        circlize (>= 0.4.16), scales (>= 1.3.0), stringr (>= 1.5.1),
        viridis (>= 0.6.5), ggplot2 (>= 3.5.1), ggraph (>= 2.2.1),
        survival (>= 3.7), survminer (>= 0.4.9), grid, stats
Suggests: rmarkdown, knitr, svglite, bookdown(>= 0.34), testthat (>=
        3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
biocViews: Software, Technology, Sequencing, RNASeq, Survival,
        Clustering, ImmunoOncology
SystemsRequirements: The `runPrd()` function requires an external
        software named PARADIGM. For details, please see the 'Required
        external software' section in vignette's 'Run PARADIGM:
        runPrd()'.
git_url: https://git.bioconductor.org/packages/MPAC
git_branch: RELEASE_3_23
git_last_commit: 2a03ee8
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 23:24:33 UTC; biocbuild
Author: Peng Liu [aut, cre] (ORCID: <https://orcid.org/0000-0001-5655-2259>),
  Paul Ahlquist [aut],
  Irene Ong [aut],
  Anthony Gitter [aut]
Maintainer: Peng Liu <pliu55.wisc+bioconductor@gmail.com>
