# Generated by roxygen2: do not edit by hand

export(clSamp)
export(colPermIPL)
export(colRealIPL)
export(conMtf)
export(fltByPerm)
export(getSignifOvrOnCl)
export(ovrGMT)
export(pltConMtf)
export(pltMtfPrtIPL)
export(pltNeiStt)
export(pltOvrHm)
export(pltSttKM)
export(ppCnInp)
export(ppPermInp)
export(ppRealInp)
export(ppRnaInp)
export(ppRunPrd)
export(runPermPrd)
export(runPrd)
export(subNtw)
import(ComplexHeatmap)
import(SingleCellExperiment)
import(data.table)
import(ggplot2)
import(ggraph)
import(igraph)
importFrom(BiocParallel,MulticoreParam)
importFrom(BiocParallel,SnowParam)
importFrom(BiocParallel,bplapply)
importFrom(BiocSingular,RandomParam)
importFrom(S4Vectors,"metadata<-")
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,metadata)
importFrom(SummarizedExperiment,"assays<-")
importFrom(SummarizedExperiment,"rowData<-")
importFrom(SummarizedExperiment,SummarizedExperiment)
importFrom(SummarizedExperiment,assays)
importFrom(bluster,NNGraphParam)
importFrom(circlize,colorRamp2)
importFrom(fgsea,gmtPathways)
importFrom(fitdistrplus,mgedist)
importFrom(grid,gpar)
importFrom(grid,unit)
importFrom(scales,percent)
importFrom(scran,clusterCells)
importFrom(scran,denoisePCA)
importFrom(scran,getTopHVGs)
importFrom(scran,modelGeneVar)
importFrom(stats,fisher.test)
importFrom(stats,mad)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stringr,str_wrap)
importFrom(survival,Surv)
importFrom(survival,survfit)
importFrom(survminer,ggsurvplot)
importFrom(viridis,cividis)
