# real.rds

```{r}
indir = system.file('/extdata/runPrd/', package='MPAC')
pat = 'TCGA-CV-7100'

MPAC::colRealIPL(indir, sampleids=c(pat))
```

# perm.rds

```{r}
indir = system.file('/extdata/runPrd/', package='MPAC')
n_perms = 3
pat = 'TCGA-CV-7100'

MPAC::colPermIPL(indir, n_perms, sampleids=c(pat))
```
